@@ -9,6 +9,7 @@ except (ImportError, SyntaxError):
 from unittest.mock import MagicMock
 from unittest import skipIf
 from functools import partial
+import weakref
 from .test_core import TestTransitions, MachineError
 from .utils import DummyModel
 from .test_graphviz import pgv as gv
@@ -51,6 +52,33 @@ class TestAsync(TestTransitions):
         self.machine_cls = MachineFactory.get_predefined(asyncio=True)
         self.machine = self.machine_cls(states=['A', 'B', 'C'], transitions=[['go', 'A', 'B']], initial='A')
 
+    def test_new_state_in_enter_callback(self):
+        machine = self.machine_cls(states=['A', 'B'], initial='A')
+
+        async def on_enter_B():
+            state = self.machine_cls.state_cls(name='C')
+            machine.add_state(state)
+            await machine.to_C()
+
+        machine.on_enter_B(on_enter_B)
+        asyncio.run(machine.to_B())
+
+    def test_dynamic_model_state_attribute(self):
+        class Model:
+            def __init__(self):
+                self.status = None
+                self.state = 'some_value'
+
+        m = self.machine_cls(Model(), states=['A', 'B'], initial='A', model_attribute='status')
+        self.assertEqual(m.model.status, 'A')
+        self.assertEqual(m.model.state, 'some_value')
+
+        m.add_transition('move', 'A', 'B')
+        asyncio.run(m.model.move())
+
+        self.assertEqual(m.model.status, 'B')
+        self.assertEqual(m.model.state, 'some_value')
+
     def test_async_machine_cb(self):
         mock = MagicMock()
 
@@ -102,8 +130,6 @@ class TestAsync(TestTransitions):
         self.assertTrue(mock.called)
 
     def test_multiple_models(self):
-        loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(loop)
 
         m1 = self.machine_cls(states=['A', 'B', 'C'], initial='A', name="m1")
         m2 = self.machine_cls(states=['A'], initial='A', name='m2')
@@ -113,12 +139,13 @@ class TestAsync(TestTransitions):
         m1.add_transition(trigger='reset', source='C', dest='A')
         m2.add_transition(trigger='go', source='A', dest=None, conditions=m1.is_C, after=m1.reset)
 
-        loop.run_until_complete(asyncio.gather(m1.go(),  # should block before B
-                                               self.call_delayed(m1.fix, 0.05),  # should cancel task and go to C
-                                               self.call_delayed(m1.check, 0.07),  # should exit before m1.fix
-                                               self.call_delayed(m2.go, 0.1)))  # should cancel m1.fix
-        assert m1.is_A()
-        loop.close()
+        async def run():
+            _ = asyncio.gather(m1.go(),  # should block before B
+                               self.call_delayed(m1.fix, 0.05),  # should cancel task and go to C
+                               self.call_delayed(m1.check, 0.07),  # should exit before m1.fix
+                               self.call_delayed(m2.go, 0.1))  # should cancel m1.fix
+            assert m1.is_A()
+        asyncio.run(run())
 
     def test_async_callback_arguments(self):
 
@@ -267,7 +294,7 @@ class TestAsync(TestTransitions):
             event_data.machine.remove_model(event_data.model)
 
         def check_queue(expect, event_data):
-            self.assertEqual(expect, len(event_data.machine._transition_queue_dict[event_data.model]))
+            self.assertEqual(expect, len(event_data.machine._transition_queue_dict[id(event_data.model)]))
 
         transitions = [
             {'trigger': 'go', 'source': 'A', 'dest': 'B', 'after': partial(asyncio.sleep, 0.1)},
@@ -289,8 +316,8 @@ class TestAsync(TestTransitions):
             self.assertTrue(m1.is_B())
             self.assertTrue(m2.is_C())
             m.remove_model(m2)
-            self.assertNotIn(m1, m._transition_queue_dict)
-            self.assertNotIn(m2, m._transition_queue_dict)
+            self.assertNotIn(id(m1), m._transition_queue_dict)
+            self.assertNotIn(id(m2), m._transition_queue_dict)
             m1 = DummyModel()
             m2 = DummyModel()
             m = self.machine_cls(model=[m1, m2], states=['A', 'B', 'C'], transitions=transitions,
@@ -372,6 +399,33 @@ class TestAsync(TestTransitions):
         asyncio.run(run())
         self.assertEqual(0, len(m.async_tasks))
 
+    def test_on_exception_callback(self):
+        mock = MagicMock()
+
+        def on_exception(event_data):
+            self.assertIsInstance(event_data.error, ValueError)
+            mock()
+
+        m = self.machine_cls(states=['A', 'B'], initial='A', send_event=True,
+                             after_state_change=partial(self.stuff.this_raises, ValueError))
+
+        async def run():
+            with self.assertRaises(ValueError):
+                await m.to_B()
+
+            m.on_exception.append(on_exception)
+            await m.to_B()
+            self.assertTrue(mock.called)
+
+        asyncio.run(run())
+
+    def test_weakproxy_model(self):
+        d = DummyModel()
+        pr = weakref.proxy(d)
+        self.machine_cls(pr, states=['A', 'B'], transitions=[['go', 'A', 'B']], initial='A')
+        asyncio.run(pr.go())
+        self.assertTrue(pr.is_B())
+
 
 @skipIf(asyncio is None or (pgv is None and gv is None), "AsyncGraphMachine requires asyncio and (py)gaphviz")
 class AsyncGraphMachine(TestAsync):
