@@ -132,8 +132,8 @@ class TestDiagrams(TestTransitions):
         m = self.machine_cls(model=[m1, m2], states=self.states, transitions=self.transitions, initial='A',
                              use_pygraphviz=self.use_pygraphviz)
         m1.walk()
-        self.assertEqual(m.model_graphs[m1].custom_styles['node'][m1.state], 'active')
-        self.assertEqual(m.model_graphs[m2].custom_styles['node'][m1.state], '')
+        self.assertEqual(m.model_graphs[id(m1)].custom_styles['node'][m1.state], 'active')
+        self.assertEqual(m.model_graphs[id(m2)].custom_styles['node'][m1.state], '')
         # backwards compatibility test
         dot1, _, _ = self.parse_dot(m1.get_graph())
         dot, _, _ = self.parse_dot(m.get_graph())
@@ -235,6 +235,17 @@ class TestDiagrams(TestTransitions):
         self.assertNotIn("label=A", dot)
         self.assertNotIn("label=event", dot)
 
+    def test_binary_stream(self):
+        from io import BytesIO
+        m = self.machine_cls(states=['A', 'B', 'C'], initial='A', auto_transitions=True,
+                             title='A test', show_conditions=True, use_pygraphviz=self.use_pygraphviz)
+        b1 = BytesIO()
+        g = m.get_graph()
+        g.draw(b1, format='png', prog='dot')
+        b2 = g.draw(None, format='png', prog='dot')
+        self.assertEqual(b2, b1.getvalue())
+        b1.close()
+
 
 @skipIf(pgv is None, 'Graph diagram test requires graphviz')
 class TestDiagramsLocked(TestDiagrams):
