@@ -271,14 +271,14 @@ class TestNestedTransitions(TestTransitions):
         self.assertEqual('ninth', m.state)
 
         # Include initial state in loop
-        m = self.stuff.machine_cls('self', states)
+        m = self.stuff.machine_cls(states=states)
         m.add_ordered_transitions(loop_includes_initial=False)
         m.to_ninth()
         m.next_state()
         self.assertEqual(m.state, 'first')
 
         # Test user-determined sequence and trigger name
-        m = self.stuff.machine_cls('self', states, initial='first')
+        m = self.stuff.machine_cls(states=states, initial='first')
         m.add_ordered_transitions(['first', 'ninth'], trigger='advance')
         m.advance()
         self.assertEqual(m.state, 'ninth')
@@ -286,7 +286,7 @@ class TestNestedTransitions(TestTransitions):
         self.assertEqual(m.state, 'first')
 
         # Via init argument
-        m = self.stuff.machine_cls('self', states, initial='first', ordered_transitions=True)
+        m = self.stuff.machine_cls(states=states, initial='first', ordered_transitions=True)
         m.next_state()
         self.assertEqual(m.state, 'first{0}second'.format(State.separator))
 
@@ -570,6 +570,63 @@ class TestNestedTransitions(TestTransitions):
         model.to_C()
         self.assertTrue(model.is_C_1())
 
+    def test_correct_subclassing(self):
+        from transitions.core import State
+
+        class WrongStateClass(self.machine_cls):
+            state_cls = State
+
+        class MyNestedState(NestedState):
+            pass
+
+        class CorrectStateClass(self.machine_cls):
+            state_cls = MyNestedState
+
+        with self.assertRaises(AssertionError):
+            m = WrongStateClass()
+        m = CorrectStateClass()
+
+    def test_queued_callbacks(self):
+        states = [
+            "initial",
+            {'name': 'A', 'children': [{'name': '1', 'on_enter': 'go'}, '2'],
+             'transitions': [['go', '1', '2']], 'initial': '1'}
+        ]
+        machine = self.machine_cls(states=states, initial='initial', queued=True)
+        machine.to_A()
+        self.assertEqual("A{0}2".format(self.state_cls.separator), machine.state)
+
+    def test_nested_transitions(self):
+        states = [{
+            'name': 'A',
+            'states': [
+                {'name': 'B',
+                 'states': [
+                     {'name': 'C',
+                      'states': ['1', '2'],
+                      'initial': '1'}],
+                 'transitions': [['go', 'C_1', 'C_2']],
+                 'initial': 'C',
+                 }],
+            'initial': 'B'
+        }]
+        machine = self.machine_cls(states=states, initial='A')
+        machine.go()
+
+    def test_auto_transitions_from_nested_callback(self):
+
+        def fail():
+            self.fail("C should not be exited!")
+
+        states = [
+            {'name': 'b', 'children': [
+                {'name': 'c', 'on_exit': fail, 'on_enter': 'to_b_c_ca', 'children': ['ca', 'cb']},
+                'd'
+            ]},
+        ]
+        machine = self.machine_cls(states=states, queued=True, initial='b')
+        machine.to_b_c()
+
 
 class TestSeparatorsBase(TestCase):
 
@@ -697,7 +754,7 @@ class TestSeparatorsBase(TestCase):
         states = ['A', 'B', {'name': 'C', 'children': ['1', '2',
                                                        {'name': '3', 'children': ['a', 'b', 'c']}]}, 'D', 'E', 'F']
 
-        machine = CustomHierarchicalGraphMachine('self', states, initial='A', auto_transitions=False,
+        machine = CustomHierarchicalGraphMachine(states=states, initial='A', auto_transitions=False,
                                                  ignore_invalid_triggers=True, use_pygraphviz=False)
         machine.add_ordered_transitions(trigger='next_state')
         machine.next_state()
@@ -727,8 +784,18 @@ class TestSeparatorsBase(TestCase):
         machine.to_C()  # exit B, enter C
         if separator == '_':
             machine.to_C_3_a()
+            self.assertTrue(machine.is_C(allow_substates=True))
+            self.assertFalse(machine.is_C())
+            self.assertTrue(machine.is_C_3(allow_substates=True))
+            self.assertFalse(machine.is_C_3())
+            self.assertTrue(machine.is_C_3_a())
         else:
             machine.to_C.s3.a()  # enter C↦a; enter C↦3↦a;
+            self.assertTrue(machine.is_C(allow_substates=True))
+            self.assertFalse(machine.is_C())
+            self.assertTrue(machine.is_C.s3(allow_substates=True))
+            self.assertFalse(machine.is_C.s3())
+            self.assertTrue(machine.is_C.s3.a())
         self.assertEqual(machine.state, 'C{0}3{0}a'.format(separator))
         machine.to('C{0}2'.format(separator))  # exit C↦3↦a, exit C↦3, enter C↦2
         self.assertEqual(machine.state, 'C{0}2'.format(separator))
