@@ -50,7 +50,11 @@ def listify(obj):
     if obj is None:
         return []
 
-    return obj if isinstance(obj, (list, tuple, EnumMeta)) else [obj]
+    try:
+        return obj if isinstance(obj, (list, tuple, EnumMeta)) else [obj]
+    except ReferenceError:
+        # obj is an empty weakref
+        return [obj]
 
 
 def _prep_ordered_arg(desired_length, arguments=None):
@@ -376,9 +380,13 @@ class Event(object):
         self.transitions[transition.source].append(transition)
 
     def trigger(self, model, *args, **kwargs):
-        """ Serially execute all transitions that match the current state,
-        halting as soon as one successfully completes.
+        """ Executes all transitions that match the current state,
+        halting as soon as one successfully completes. More precisely, it prepares a partial
+        of the internal ``_trigger`` function, passes this to ``Machine._process``.
+        It is up to the machine's configuration of the Event whether processing happens queued (sequentially) or
+        whether further Events are processed as they occur.
         Args:
+            model (object): The currently processed model
             args and kwargs: Optional positional or named arguments that will
                 be passed onto the EventData object, enabling arbitrary state
                 information to be passed on to downstream triggered functions.
@@ -394,7 +402,14 @@ class Event(object):
 
     def _trigger(self, model, *args, **kwargs):
         """ Internal trigger function called by the ``Machine`` instance. This should not
-        be called directly but via the public method ``Machine.trigger``.
+        be called directly but via the public method ``Machine.process``.
+        Args:
+            model (object): The currently processed model
+            args and kwargs: Optional positional or named arguments that will
+                be passed onto the EventData object, enabling arbitrary state
+                information to be passed on to downstream triggered functions.
+        Returns: boolean indicating whether or not a transition was
+            successfully executed (True if successful, False if not).
         """
         state = self.machine.get_model_state(model)
         if state.name not in self.transitions:
@@ -422,10 +437,19 @@ class Event(object):
                     break
         except Exception as err:
             event_data.error = err
-            raise
+            if self.machine.on_exception:
+                self.machine.callbacks(self.machine.on_exception, event_data)
+            else:
+                raise
         finally:
-            self.machine.callbacks(self.machine.finalize_event, event_data)
-            _LOGGER.debug("%sExecuted machine finalize callbacks", self.machine.name)
+            try:
+                self.machine.callbacks(self.machine.finalize_event, event_data)
+                _LOGGER.debug("%sExecuted machine finalize callbacks", self.machine.name)
+            except Exception as err:
+                _LOGGER.error("%sWhile executing finalize callbacks a %s occurred: %s.",
+                              self.machine.name,
+                              type(err).__name__,
+                              str(err))
 
         return event_data.result
 
@@ -478,16 +502,18 @@ class Machine(object):
     state_cls = State
     transition_cls = Transition
     event_cls = Event
+    self_literal = 'self'
 
-    def __init__(self, model='self', states=None, initial='initial', transitions=None,
+    def __init__(self, model=self_literal, states=None, initial='initial', transitions=None,
                  send_event=False, auto_transitions=True,
                  ordered_transitions=False, ignore_invalid_triggers=None,
                  before_state_change=None, after_state_change=None, name=None,
-                 queued=False, prepare_event=None, finalize_event=None, model_attribute='state', **kwargs):
+                 queued=False, prepare_event=None, finalize_event=None, model_attribute='state', on_exception=None,
+                 **kwargs):
         """
         Args:
-            model (object or list): The object(s) whose states we want to manage. If 'self',
-                the current Machine instance will be used the model (i.e., all
+            model (object or list): The object(s) whose states we want to manage. If set to `Machine.self_literal`
+                (default value), the current Machine instance will be used as the model (i.e., all
                 triggering events will be attached to the Machine itself). Note that an empty list
                 is treated like no model.
             states (list or Enum): A list or enumeration of valid states. Each list element can be either a
@@ -527,6 +553,8 @@ class Machine(object):
                 It receives the very same args as normal callbacks.
             finalize_event: A callable called on for each triggered event after transitions have been processed.
                 This is also called when a transition raises an exception.
+            on_exception: A callable called when an event raises an exception. If not set,
+                the exception will be raised instead.
 
             **kwargs additional arguments passed to next class in MRO. This can be ignored in most cases.
         """
@@ -545,6 +573,7 @@ class Machine(object):
         self._after_state_change = []
         self._prepare_event = []
         self._finalize_event = []
+        self._on_exception = []
         self._initial = None
 
         self.states = OrderedDict()
@@ -556,6 +585,7 @@ class Machine(object):
         self.before_state_change = before_state_change
         self.after_state_change = after_state_change
         self.finalize_event = finalize_event
+        self.on_exception = on_exception
         self.name = name + ": " if name is not None else ""
         self.model_attribute = model_attribute
 
@@ -587,7 +617,7 @@ class Machine(object):
                 initial = self.initial
 
         for mod in models:
-            mod = self if mod == 'self' else mod
+            mod = self if mod is self.self_literal else mod
             if mod not in self.models:
                 self._checked_assignment(mod, 'trigger', partial(self._get_trigger, mod))
 
@@ -702,6 +732,16 @@ class Machine(object):
     def finalize_event(self, value):
         self._finalize_event = listify(value)
 
+    @property
+    def on_exception(self):
+        """Callbacks will be executed when an Event raises an Exception."""
+        return self._on_exception
+
+    # this should make sure that finalize_event is always a list
+    @on_exception.setter
+    def on_exception(self, value):
+        self._on_exception = listify(value)
+
     def get_state(self, state):
         """ Return the State instance with the passed name. """
         if isinstance(state, Enum):
@@ -866,8 +906,8 @@ class Machine(object):
         Returns:
             list of transition/trigger names.
         """
-        states = set(args)
-        return [t for (t, ev) in self.events.items() if any(state in ev.transitions for state in states)]
+        names = set([state.name if hasattr(state, 'name') else state for state in args])
+        return [t for (t, ev) in self.events.items() if any(name in ev.transitions for name in names)]
 
     def add_transition(self, trigger, source, dest, conditions=None,
                        unless=None, before=None, after=None, prepare=None, **kwargs):
