@@ -136,12 +136,12 @@ class AsyncTransition(Transition):
 
     async def _change_state(self, event_data):
         if hasattr(event_data.machine, "model_graphs"):
-            graph = event_data.machine.model_graphs[event_data.model]
+            graph = event_data.machine.model_graphs[id(event_data.model)]
             graph.reset_styling()
             graph.set_previous_transition(self.source, self.dest)
         await event_data.machine.get_state(self.source).exit(event_data)
         event_data.machine.set_state(self.dest, event_data.model)
-        event_data.update(event_data.model.state)
+        event_data.update(getattr(event_data.model, event_data.machine.model_attribute))
         await event_data.machine.get_state(self.dest).enter(event_data)
 
 
@@ -149,7 +149,7 @@ class NestedAsyncTransition(AsyncTransition, NestedTransition):
 
     async def _change_state(self, event_data):
         if hasattr(event_data.machine, "model_graphs"):
-            graph = event_data.machine.model_graphs[event_data.model]
+            graph = event_data.machine.model_graphs[id(event_data.model)]
             graph.reset_styling()
             graph.set_previous_transition(self.source, self.dest)
         state_tree, exit_partials, enter_partials = self._resolve_transition(event_data)
@@ -177,7 +177,7 @@ class AsyncEvent(Event):
         return await self.machine.process_context(func, _model)
 
     async def _trigger(self, model, *args, **kwargs):
-        state = self.machine.get_state(model.state)
+        state = self.machine.get_state(getattr(model, self.machine.model_attribute))
         if state.name not in self.transitions:
             msg = "%sCan't trigger event %s from state %s!" % (self.machine.name, self.name,
                                                                state.name)
@@ -203,7 +203,10 @@ class AsyncEvent(Event):
                     break
         except Exception as err:
             event_data.error = err
-            raise
+            if self.machine.on_exception:
+                await self.machine.callbacks(self.machine.on_exception, event_data)
+            else:
+                raise
         finally:
             await self.machine.callbacks(self.machine.finalize_event, event_data)
             _LOGGER.debug("%sExecuted machine finalize callbacks", self.machine.name)
@@ -263,7 +266,10 @@ class NestedAsyncEvent(NestedEvent):
                     break
         except Exception as err:
             event_data.error = err
-            raise
+            if self.machine.on_exception:
+                await self.machine.callbacks(self.machine.on_exception, event_data)
+            else:
+                raise
         finally:
             await machine.callbacks(machine.finalize_event, event_data)
             _LOGGER.debug("%sExecuted machine finalize callbacks", machine.name)
@@ -287,6 +293,8 @@ class AsyncMachine(Machine):
             Callbacks will be executed AFTER the custom callbacks assigned to the transition.
         finalize_event (list): Callbacks will be executed after all transitions callbacks have been executed.
             Callbacks mentioned here will also be called if a transition or condition check raised an error.
+        on_exception: A callable called when an event raises an exception. If not set,
+            the Exception will be raised instead.
         queued (bool): Whether transitions in callbacks should be executed immediately (False) or sequentially.
         send_event (bool): When True, any arguments passed to trigger methods will be wrapped in an EventData
             object, allowing indirect and encapsulated access to data. When False, all positional and keyword
@@ -318,7 +326,7 @@ class AsyncMachine(Machine):
         super().add_model(model, initial)
         if self.has_queue == 'model':
             for mod in listify(model):
-                self._transition_queue_dict[mod if mod != 'self' else self] = deque()
+                self._transition_queue_dict[id(self) if mod is self.self_literal else id(mod)] = deque()
 
     async def dispatch(self, trigger, *args, **kwargs):  # ToDo: not tested
         """ Trigger an event on all models assigned to the machine.
@@ -373,7 +381,7 @@ class AsyncMachine(Machine):
         Args:
             model (object): The currently processed model
         """
-        for running_task in self.async_tasks.get(model, []):
+        for running_task in self.async_tasks.get(id(model), []):
             if self.current_context.get() == running_task or running_task in self.protected_tasks:
                 continue
             elif running_task.done() is False:
@@ -393,18 +401,18 @@ class AsyncMachine(Machine):
         """
         if self.current_context.get() is None:
             self.current_context.set(asyncio.current_task())
-            if model in self.async_tasks:
-                self.async_tasks[model].append(asyncio.current_task())
+            if id(model) in self.async_tasks:
+                self.async_tasks[id(model)].append(asyncio.current_task())
             else:
-                self.async_tasks[model] = [asyncio.current_task()]
+                self.async_tasks[id(model)] = [asyncio.current_task()]
             try:
                 res = await self._process(func, model)
             except asyncio.CancelledError:
                 res = False
             finally:
-                self.async_tasks[model].remove(asyncio.current_task())
-                if len(self.async_tasks[model]) == 0:
-                    del self.async_tasks[model]
+                self.async_tasks[id(model)].remove(asyncio.current_task())
+                if len(self.async_tasks[id(model)]) == 0:
+                    del self.async_tasks[id(model)]
         else:
             res = await self._process(func, model)
         return res
@@ -416,7 +424,11 @@ class AsyncMachine(Machine):
         models = listify(model)
         if self.has_queue == 'model':
             for mod in models:
-                del self._transition_queue_dict[mod]
+                del self._transition_queue_dict[id(mod)]
+                self.models.remove(mod)
+        else:
+            for mod in models:
+                self.models.remove(mod)
         if len(self._transition_queue) > 0:
             queue = self._transition_queue
             new_queue = [queue.popleft()] + [e for e in queue if e.args[0] not in models]
@@ -432,20 +444,20 @@ class AsyncMachine(Machine):
             else:
                 raise MachineError("Attempt to process events synchronously while transition queue is not empty!")
 
-        self._transition_queue_dict[model].append(trigger)
+        self._transition_queue_dict[id(model)].append(trigger)
         # another entry in the queue implies a running transition; skip immediate execution
-        if len(self._transition_queue_dict[model]) > 1:
+        if len(self._transition_queue_dict[id(model)]) > 1:
             return True
 
-        while self._transition_queue_dict[model]:
+        while self._transition_queue_dict[id(model)]:
             try:
-                await self._transition_queue_dict[model][0]()
+                await self._transition_queue_dict[id(model)][0]()
             except Exception:
                 # if a transition raises an exception, clear queue and delegate exception handling
-                self._transition_queue_dict[model].clear()
+                self._transition_queue_dict[id(model)].clear()
                 raise
             try:
-                self._transition_queue_dict[model].popleft()
+                self._transition_queue_dict[id(model)].popleft()
             except KeyError:
                 return True
         return True
@@ -480,7 +492,8 @@ class HierarchicalAsyncMachine(HierarchicalMachine, AsyncMachine):
 
     async def _trigger_event(self, _model, _trigger, _state_tree, *args, **kwargs):
         if _state_tree is None:
-            _state_tree = self._build_state_tree(listify(getattr(_model, self.model_attribute)), self.state_cls.separator)
+            _state_tree = self._build_state_tree(listify(getattr(_model, self.model_attribute)),
+                                                 self.state_cls.separator)
         res = {}
         for key, value in _state_tree.items():
             if value:
