@@ -2,7 +2,6 @@ from transitions import Transition
 from transitions.extensions.markup import MarkupMachine
 from transitions.core import listify
 
-import warnings
 import logging
 from functools import partial
 import copy
@@ -10,9 +9,6 @@ import copy
 _LOGGER = logging.getLogger(__name__)
 _LOGGER.addHandler(logging.NullHandler())
 
-# make deprecation warnings of transition visible for module users
-warnings.filterwarnings(action='default', message=r".*transitions version.*")
-
 # this is a workaround for dill issues when partials and super is used in conjunction
 # without it, Python 3.0 - 3.3 will not support pickling
 # https://github.com/pytransitions/transitions/issues/236
@@ -24,11 +20,18 @@ class TransitionGraphSupport(Transition):
         conducted.
     """
 
+    def __init__(self, *args, **kwargs):
+        label = kwargs.pop('label', None)
+        _super(TransitionGraphSupport, self).__init__(*args, **kwargs)
+        if label:
+            self.label = label
+
     def _change_state(self, event_data):
-        graph = event_data.machine.model_graphs[event_data.model]
+        graph = event_data.machine.model_graphs[id(event_data.model)]
         graph.reset_styling()
         graph.set_previous_transition(self.source, self.dest, event_data.event.name)
         _super(TransitionGraphSupport, self)._change_state(event_data)  # pylint: disable=protected-access
+        graph = event_data.machine.model_graphs[id(event_data.model)]  # graph might have changed during change_event
         for state in _flatten(listify(getattr(event_data.model, event_data.machine.model_attribute))):
             graph.set_node_style(self.dest if hasattr(state, 'name') else state, 'active')
 
@@ -61,16 +64,23 @@ class GraphMachine(MarkupMachine):
         'node': {
             '': {},
             'default': {
-                'shape': 'rectangle',
                 'style': 'rounded, filled',
+                'shape': 'rectangle',
+                'fillcolor': 'white',
+                'color': 'black',
+                'peripheries': '1'
+            },
+            'inactive': {
                 'fillcolor': 'white',
                 'color': 'black',
                 'peripheries': '1'
             },
             'parallel': {
+                'shape': 'rectangle',
                 'color': 'black',
                 'fillcolor': 'white',
-                'style': 'dashed, rounded, filled'
+                'style': 'dashed, rounded, filled',
+                'peripheries': '1'
             },
             'active': {
                 'color': 'red',
@@ -181,17 +191,17 @@ class GraphMachine(MarkupMachine):
     def _get_graph(self, model, title=None, force_new=False, show_roi=False):
         if force_new:
             grph = self.graph_cls(self, title=title if title is not None else self.title)
-            self.model_graphs[model] = grph
+            self.model_graphs[id(model)] = grph
             try:
-                state = getattr(model, self.model_attribute)
-                self.model_graphs[model].set_node_style(state.name if hasattr(state, 'name') else state, 'active')
+                for state in _flatten(listify(getattr(model, self.model_attribute))):
+                    grph.set_node_style(self.dest if hasattr(state, 'name') else state, 'active')
             except AttributeError:
                 _LOGGER.info("Could not set active state of diagram")
         try:
-            m = self.model_graphs[model]
+            m = self.model_graphs[id(model)]
         except KeyError:
             _ = self._get_graph(model, title, force_new=True)
-            m = self.model_graphs[model]
+            m = self.model_graphs[id(model)]
         m.roi_state = getattr(model, self.model_attribute) if show_roi else None
         return m.get_graph(title=title)
 
@@ -214,7 +224,7 @@ class GraphMachine(MarkupMachine):
         models = listify(model)
         super(GraphMachine, self).add_model(models, initial)
         for mod in models:
-            mod = self if mod == 'self' else mod
+            mod = self if mod is self.self_literal else mod
             if hasattr(mod, 'get_graph'):
                 raise AttributeError('Model already has a get_graph attribute. Graph retrieval cannot be bound.')
             setattr(mod, 'get_graph', partial(self._get_graph, mod))
